import { isMongoId } from 'class-validator';
import { Types } from 'mongoose';
import { RESTError } from '../models/dtos/wrappers/rest-wrapper.class';

const toStringArray = (value: string | string[]) => {
    return typeof value === 'string' ? [value] : value;
};

const toMongoId = (value: string) => {
    const check = isMongoId(value);
    if (!check) {
        throw new RESTError('invalid_mongoid', value);
    }
    return Types.ObjectId.createFromHexString(value);
};

const toMongoIdArray = (values: string | string[]) => {
    const result: Types.ObjectId[] = [];
    const items = typeof values === 'string' ? [values] : values;
    for (const value of items) {
        result.push(toMongoId(value));
    }
    return result;
};

const toBoolean = (value: string) => {
    return value === 'true';
};

const toInt64 = (value: string) => {
    try {
        // Convert the string to a BigInt
        const int64Value = BigInt(value);

        // Ensure it's within the 64-bit integer range
        const int64Min = BigInt('-9223372036854775808');
        const int64Max = BigInt('9223372036854775807');
        if (int64Value < int64Min || int64Value > int64Max) {
            throw new RESTError('conversion_error', 'Value is out of the 64-bit signed integer range.');
        }
        return int64Value;
    } catch (error) {
        throw new RESTError('conversion_error_invalid_input', `Invalid input for conversion to Int64: ${error.message}`);
    }
};

export { toStringArray, toMongoId, toMongoIdArray, toBoolean, toInt64 };
